@@ -1,6 +1,6 @@
-"""client of DfCx agent - tracks session internally"""
+"""DFCX End to End Conversation Functions"""
 
-# Copyright 2021 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -35,14 +35,13 @@ logger = logging
 
 logging.basicConfig(format="[dfcx] %(levelname)s:%(message)s", level=None)
 
-MAX_RETRIES = 3  # JWT errors on CX API
+MAX_RETRIES = 3
 DEBUG_LEVEL = "info"
 
 
 class DialogflowConversation(ScrapiBase):
-    """
-    wrapping client requests to a CX agent for a conversation
-    with internally maintained session state
+    """Class that wraps the SessionsClient to hold end to end conversations
+    and maintain internal session state
     """
 
     def __init__(
@@ -80,6 +79,20 @@ class DialogflowConversation(ScrapiBase):
         self.flows = Flows(creds=self.creds)
         self.pages = Pages(creds=self.creds)
 
+    @staticmethod
+    def _get_match_type_from_map(match_type:int):
+        match_type_map = {
+            0: 'MATCH_TYPE_UNSPECIFIED',
+            1: 'INTENT',
+            2: 'DIRECT_INTENT',
+            3: 'PARAMETER_FILLING',
+            4: 'NO_MATCH',
+            5: 'NO_INPUT',
+            6: 'EVENT'
+        }
+
+        return match_type_map[match_type]
+
     @staticmethod
     def _validate_test_set_input(test_set: pd.DataFrame):
         mask = test_set.page_id.isna().to_list()
@@ -87,10 +100,9 @@ class DialogflowConversation(ScrapiBase):
 
         if invalid_pages:
             raise Exception("The following Pages are invalid and missing Page "
-                "IDs: \n%s\n\nPlease ensure that your Page Display Names do "
-                "not contain typos.\nFor Default Start Page use the special "
-                "page display name START_PAGE." % invalid_pages)
-
+                f"IDs: \n{invalid_pages}\n\nPlease ensure that your Page "
+                "Display Names do not contain typos.\nFor Default Start Page "
+                "use the special page display name START_PAGE.")
 
     @staticmethod
     def progress_bar(current, total, bar_length=50, type_="Progress"):
@@ -98,11 +110,9 @@ class DialogflowConversation(ScrapiBase):
         percent = float(current) * 100 / total
         arrow = "-" * int(percent / 100 * bar_length - 1) + ">"
         spaces = " " * (bar_length - len(arrow))
-        print(
-            "{2}({0}/{1})".format(current, total, type_)
-            + "[%s%s] %d %%" % (arrow, spaces, percent),
-            end="\r",
-        )
+        print(f"{type_}({current}/{total})" + f"[{arrow}{spaces}] {percent}%",
+          end="\r")
+
 
     def _page_id_mapper(self):
         agent_pages_map = pd.DataFrame()
@@ -148,7 +158,7 @@ class DialogflowConversation(ScrapiBase):
         confidence = response["confidence"]
         target_page = response["page_name"]
 
-        results["detected_intent"][i] = intent or "no match"
+        results["detected_intent"][i] = intent or "NO_MATCH"
         results["confidence"][i] = confidence
         results["target_page"][i] = target_page
 
@@ -219,7 +229,7 @@ class DialogflowConversation(ScrapiBase):
         duration = round((time.perf_counter() - start_time), 2)
         if duration > 2:
             if msg:
-                print("{:0.2f}s {}".format(duration, msg))
+                print(f"{duration:0.2f}s {msg}")
 
     def reply(
         self,
@@ -265,16 +275,12 @@ class DialogflowConversation(ScrapiBase):
         )
         session_path = f"{self.agent_path}/sessions/{self.session_id}"
 
-        # projects/*/locations/*/agents/*/environments/*/sessions/*
         custom_environment = self.agent_env.get("environment")
 
         if custom_environment:
-            # just the environment and NOT experiment
-            # (change to elif if experiment comes back)
             logging.info("req using env: %s", custom_environment)
-            session_path = "{}/environments/{}/sessions/{}".format(
-                self.agent_path, custom_environment, self.session_id
-            )
+            session_path = f"{self.agent_path}/environments/"\
+            f"{custom_environment}/sessions/{self.session_id}"
 
         disable_webhook = self.agent_env.get("disable_webhook") or False
 
@@ -312,7 +318,6 @@ class DialogflowConversation(ScrapiBase):
                 language_code=self.language_code,
             )
 
-        # self.checkpoint("<< prepared request")
         request = session.DetectIntentRequest(
             session=session_path,
             query_input=query_input,
@@ -349,45 +354,38 @@ class DialogflowConversation(ScrapiBase):
             logging.error(traceback.print_exc())
             retries += 1
             if retries < MAX_RETRIES:
-                # TODO - increase back off / delay? not needed for 3 retries
                 logging.error("retrying")
                 return self.reply(
                     send_obj, restart=restart, raw=raw, retries=retries
                 )
             else:
                 logging.error("MAX_RETRIES exceeded")
-                # try to continue but this may crash somewhere else
                 return {}
-                # raise err
-                # return None ## try next one
 
-        # format reply
+
         if checkpoints:
             self.checkpoint("<< got response")
         query_result = response.query_result
         logging.debug("dfcx>qr %s", query_result)
-        self.query_result = query_result  # for debugging
+        self.query_result = query_result
         reply = {}
 
         # flatten array of text responses
         texts = []
         for msg in query_result.response_messages:
             if msg.payload:
-                reply["payload"] = ScrapiBase.extract_payload(msg)
+                # reply["text"] = ScrapiBase.extract_payload(msg)
+                texts.append(str(ScrapiBase.extract_payload(msg)))
             if (len(msg.text.text)) > 0:
-                text = msg.text.text[-1]  # this could be multiple lines too?
-                # print("text", text)
+                text = msg.text.text[-1]
                 texts.append(text)
 
         # flatten params struct
         params = {}
-        # print("parameters", json.dumps(qr.parameters))  ## not JSON
         if query_result.parameters:
             for param in query_result.parameters:
-                # turn into key: value pairs
                 val = query_result.parameters[param]
                 try:
-                    # protobuf array - we flatten as a string with spaces
                     if isinstance(val, RepeatedComposite):
                         val = " ".join(val)
 
@@ -406,18 +404,13 @@ class DialogflowConversation(ScrapiBase):
         reply["confidence"] = query_result.intent_detection_confidence
         reply["page_name"] = query_result.current_page.display_name
         reply["intent_name"] = query_result.intent.display_name
+        reply["match_type"] = self._get_match_type_from_map(
+            query_result.match.match_type)
         reply["other_intents"] = self.format_other_intents(query_result)
         reply["params"] = params
 
-        if DEBUG_LEVEL == "silly":
-            blob = ScrapiBase.cx_object_to_json(query_result)
-            logging.info(
-                "response: %s", json.dumps(blob, indent=2)
-            )  # do NOT deploy
-            # logging.debug("response: %s", blob)
-
-        # self.checkpoint("<< formatted response")
         logging.debug("reply %s", reply)
+
         return reply
 
     def format_other_intents(self, query_result):
@@ -436,8 +429,8 @@ class DialogflowConversation(ScrapiBase):
                 }
             )
             rank += 1
-        # intents_map[alt["DisplayName"]] = alt["Score"]
-        if self:  # keep as instance method and silence linter
+
+        if self:
             return items
 
         return None
